import sys
import unittest

import smscx_client
from smscx_client.model.data_groups_details import DataGroupsDetails
from smscx_client.model.info_groups import InfoGroups
from smscx_client.model.paging import Paging
globals()['DataGroupsDetails'] = DataGroupsDetails
globals()['InfoGroups'] = InfoGroups
globals()['Paging'] = Paging
from smscx_client.model.group_details_response import GroupDetailsResponse


class TestGroupDetailsResponse(unittest.TestCase):
    """GroupDetailsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGroupDetailsResponse(self):
        """Test GroupDetailsResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GroupDetailsResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from smscx_client.model.campaigns import Campaigns
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from smscx_client.model.accepted import Accepted
from smscx_client.model.account_balance import AccountBalance
from smscx_client.model.add_contacts_to_group400_response import AddContactsToGroup400Response
from smscx_client.model.add_contacts_to_group_request import AddContactsToGroupRequest
from smscx_client.model.add_contacts_to_group_response import AddContactsToGroupResponse
from smscx_client.model.add_contacts_to_group_with_fields_request import AddContactsToGroupWithFieldsRequest
from smscx_client.model.alerts import Alerts
from smscx_client.model.application_settings_response import ApplicationSettingsResponse
from smscx_client.model.applications_list_response import ApplicationsListResponse
from smscx_client.model.attachment_delete_response import AttachmentDeleteResponse
from smscx_client.model.attachment_details_response import AttachmentDetailsResponse
from smscx_client.model.attachment_list_response import AttachmentListResponse
from smscx_client.model.attachments import Attachments
from smscx_client.model.call_back_request_attachment_hit import CallBackRequestAttachmentHit
from smscx_client.model.call_back_request_dlr_update import CallBackRequestDlrUpdate
from smscx_client.model.call_back_request_new_optout import CallBackRequestNewOptout
from smscx_client.model.call_back_request_number_lookup import CallBackRequestNumberLookup
from smscx_client.model.call_back_request_otp_update import CallBackRequestOtpUpdate
from smscx_client.model.call_back_request_receive_sms import CallBackRequestReceiveSms
from smscx_client.model.call_back_request_shortlink_hit import CallBackRequestShortlinkHit
from smscx_client.model.callback_event_types import CallbackEventTypes
from smscx_client.model.campaigns import Campaigns
from smscx_client.model.cancel_otp_response import CancelOtpResponse
from smscx_client.model.cancel_rent_response import CancelRentResponse
from smscx_client.model.channels_status import ChannelsStatus
from smscx_client.model.characters_replaced import CharactersReplaced
from smscx_client.model.conversation_details_response import ConversationDetailsResponse
from smscx_client.model.conversation_read_response import ConversationReadResponse
from smscx_client.model.conversation_reply_sms_request import ConversationReplySmsRequest
from smscx_client.model.conversation_reply_sms_response import ConversationReplySmsResponse
from smscx_client.model.conversation_reply_viber_request import ConversationReplyViberRequest
from smscx_client.model.conversation_reply_viber_respone import ConversationReplyViberRespone
from smscx_client.model.conversation_reply_whatsapp_request import ConversationReplyWhatsappRequest
from smscx_client.model.conversation_reply_whatsapp_response import ConversationReplyWhatsappResponse
from smscx_client.model.conversations_list_response import ConversationsListResponse
from smscx_client.model.country_price_obj import CountryPriceObj
from smscx_client.model.country_price_obj1 import CountryPriceObj1
from smscx_client.model.custom_fields import CustomFields
from smscx_client.model.custom_fields_obj import CustomFieldsObj
from smscx_client.model.data_applications_list import DataApplicationsList
from smscx_client.model.data_attachment import DataAttachment
from smscx_client.model.data_available_numbers_rent import DataAvailableNumbersRent
from smscx_client.model.data_conversation import DataConversation
from smscx_client.model.data_conversation_reply import DataConversationReply
from smscx_client.model.data_conversations import DataConversations
from smscx_client.model.data_dlr_update import DataDlrUpdate
from smscx_client.model.data_groups import DataGroups
from smscx_client.model.data_groups_details import DataGroupsDetails
from smscx_client.model.data_multichannel import DataMultichannel
from smscx_client.model.data_new_optout import DataNewOptout
from smscx_client.model.data_number_lookup import DataNumberLookup
from smscx_client.model.data_number_lookup_webhook import DataNumberLookupWebhook
from smscx_client.model.data_number_validate import DataNumberValidate
from smscx_client.model.data_numbers_lookup import DataNumbersLookup
from smscx_client.model.data_numbers_validate import DataNumbersValidate
from smscx_client.model.data_optouts import DataOptouts
from smscx_client.model.data_originators_list import DataOriginatorsList
from smscx_client.model.data_otp import DataOtp
from smscx_client.model.data_receive_sms import DataReceiveSms
from smscx_client.model.data_rented_numbers import DataRentedNumbers
from smscx_client.model.data_report_campaign import DataReportCampaign
from smscx_client.model.data_reports import DataReports
from smscx_client.model.data_reports_campaigns import DataReportsCampaigns
from smscx_client.model.data_shortlink_detail import DataShortlinkDetail
from smscx_client.model.data_shortlink_hit import DataShortlinkHit
from smscx_client.model.data_shortlink_list import DataShortlinkList
from smscx_client.model.data_sms import DataSms
from smscx_client.model.data_summary import DataSummary
from smscx_client.model.data_summary_delivery import DataSummaryDelivery
from smscx_client.model.data_template import DataTemplate
from smscx_client.model.data_templates_list import DataTemplatesList
from smscx_client.model.data_viber import DataViber
from smscx_client.model.data_whatsapp import DataWhatsapp
from smscx_client.model.delete_contact import DeleteContact
from smscx_client.model.delete_group import DeleteGroup
from smscx_client.model.delete_scheduled_campaign import DeleteScheduledCampaign
from smscx_client.model.delete_scheduled_msg import DeleteScheduledMsg
from smscx_client.model.delivered import Delivered
from smscx_client.model.error import Error
from smscx_client.model.failed import Failed
from smscx_client.model.get_channel_pricing200_response import GetChannelPricing200Response
from smscx_client.model.get_inbound_sms_response import GetInboundSMSResponse
from smscx_client.model.get_rent_status_response import GetRentStatusResponse
from smscx_client.model.get_summary_reports200_response import GetSummaryReports200Response
from smscx_client.model.group import Group
from smscx_client.model.group_add import GroupAdd
from smscx_client.model.group_add_custom_fields import GroupAddCustomFields
from smscx_client.model.group_details_response import GroupDetailsResponse
from smscx_client.model.group_response import GroupResponse
from smscx_client.model.groups_list import GroupsList
from smscx_client.model.info import Info
from smscx_client.model.info_attachment import InfoAttachment
from smscx_client.model.info_campaign import InfoCampaign
from smscx_client.model.info_cancel_rent import InfoCancelRent
from smscx_client.model.info_conversation import InfoConversation
from smscx_client.model.info_conversation_reply import InfoConversationReply
from smscx_client.model.info_delete_group import InfoDeleteGroup
from smscx_client.model.info_delete_scheduled_campaign import InfoDeleteScheduledCampaign
from smscx_client.model.info_delete_scheduled_msg import InfoDeleteScheduledMsg
from smscx_client.model.info_group import InfoGroup
from smscx_client.model.info_groups import InfoGroups
from smscx_client.model.info_groups_add_contacts_response import InfoGroupsAddContactsResponse
from smscx_client.model.info_groups_contact_deleted import InfoGroupsContactDeleted
from smscx_client.model.info_id import InfoId
from smscx_client.model.info_inbound_sms import InfoInboundSms
from smscx_client.model.info_multichannel import InfoMultichannel
from smscx_client.model.info_multichannel_campaign import InfoMultichannelCampaign
from smscx_client.model.info_new_group import InfoNewGroup
from smscx_client.model.info_numbers_lookup import InfoNumbersLookup
from smscx_client.model.info_numbers_validate import InfoNumbersValidate
from smscx_client.model.info_optout import InfoOptout
from smscx_client.model.info_optouts import InfoOptouts
from smscx_client.model.info_optouts_new import InfoOptoutsNew
from smscx_client.model.info_originator import InfoOriginator
from smscx_client.model.info_otp import InfoOtp
from smscx_client.model.info_phone_number_update import InfoPhoneNumberUpdate
from smscx_client.model.info_rent_number import InfoRentNumber
from smscx_client.model.info_report_campaign import InfoReportCampaign
from smscx_client.model.info_reports import InfoReports
from smscx_client.model.info_reports_campaigns import InfoReportsCampaigns
from smscx_client.model.info_shortlink_detail import InfoShortlinkDetail
from smscx_client.model.info_shortlink_new import InfoShortlinkNew
from smscx_client.model.info_template import InfoTemplate
from smscx_client.model.info_template_update import InfoTemplateUpdate
from smscx_client.model.info_viber import InfoViber
from smscx_client.model.info_viber_campaign import InfoViberCampaign
from smscx_client.model.info_whatsapp import InfoWhatsapp
from smscx_client.model.lookup import Lookup
from smscx_client.model.model400_invalid_param import Model400InvalidParam
from smscx_client.model.model400_invalid_param_groups import Model400InvalidParamGroups
from smscx_client.model.model400_invalid_phone_numbers import Model400InvalidPhoneNumbers
from smscx_client.model.model401_invalid_client import Model401InvalidClient
from smscx_client.model.model401_unauthorized import Model401Unauthorized
from smscx_client.model.model403_insufficient_scope import Model403InsufficientScope
from smscx_client.model.model403_no_coverage import Model403NoCoverage
from smscx_client.model.model404_not_found import Model404NotFound
from smscx_client.model.model500_server_error import Model500ServerError
from smscx_client.model.multichannel import Multichannel
from smscx_client.model.network_operator import NetworkOperator
from smscx_client.model.new_group_request import NewGroupRequest
from smscx_client.model.new_group_response import NewGroupResponse
from smscx_client.model.new_otp_request import NewOtpRequest
from smscx_client.model.new_otp_response import NewOtpResponse
from smscx_client.model.no_coverage import NoCoverage
from smscx_client.model.number_lookup_response import NumberLookupResponse
from smscx_client.model.number_validate_response import NumberValidateResponse
from smscx_client.model.numbers_bulk_lookup_result import NumbersBulkLookupResult
from smscx_client.model.numbers_lookup_request import NumbersLookupRequest
from smscx_client.model.numbers_lookup_response import NumbersLookupResponse
from smscx_client.model.numbers_validate_request import NumbersValidateRequest
from smscx_client.model.numbers_validate_response import NumbersValidateResponse
from smscx_client.model.oauth_token_response import OauthTokenResponse
from smscx_client.model.optouts import Optouts
from smscx_client.model.optouts_delete_response import OptoutsDeleteResponse
from smscx_client.model.optouts_list_response import OptoutsListResponse
from smscx_client.model.optouts_new_request import OptoutsNewRequest
from smscx_client.model.optouts_new_response import OptoutsNewResponse
from smscx_client.model.original_network import OriginalNetwork
from smscx_client.model.original_text import OriginalText
from smscx_client.model.originator_new_request import OriginatorNewRequest
from smscx_client.model.originator_new_response import OriginatorNewResponse
from smscx_client.model.originators_list_response import OriginatorsListResponse
from smscx_client.model.otp import Otp
from smscx_client.model.paging import Paging
from smscx_client.model.phone_numbers_by_country import PhoneNumbersByCountry
from smscx_client.model.ported_network import PortedNetwork
from smscx_client.model.pricing_sms_response import PricingSmsResponse
from smscx_client.model.pricing_viber_whatsapp_response import PricingViberWhatsappResponse
from smscx_client.model.quiet_hours import QuietHours
from smscx_client.model.renew_rent_request import RenewRentRequest
from smscx_client.model.rent_number_request import RentNumberRequest
from smscx_client.model.rent_number_response import RentNumberResponse
from smscx_client.model.rent_numbers_response import RentNumbersResponse
from smscx_client.model.rental_cost import RentalCost
from smscx_client.model.rented_numbers_response import RentedNumbersResponse
from smscx_client.model.replaced_text import ReplacedText
from smscx_client.model.report_single_response import ReportSingleResponse
from smscx_client.model.reports_advanced_response import ReportsAdvancedResponse
from smscx_client.model.reports_campaign_response import ReportsCampaignResponse
from smscx_client.model.reports_campaigns_respone import ReportsCampaignsRespone
from smscx_client.model.reports_summary_channel_response import ReportsSummaryChannelResponse
from smscx_client.model.reports_summary_channel_response_data_value import ReportsSummaryChannelResponseDataValue
from smscx_client.model.reports_summary_country_response import ReportsSummaryCountryResponse
from smscx_client.model.reports_summary_country_response_data_value import ReportsSummaryCountryResponseDataValue
from smscx_client.model.reports_summary_delivery_response import ReportsSummaryDeliveryResponse
from smscx_client.model.reports_summary_delivery_response_data_value import ReportsSummaryDeliveryResponseDataValue
from smscx_client.model.reports_summary_source_response import ReportsSummarySourceResponse
from smscx_client.model.reports_summary_source_response_data_value import ReportsSummarySourceResponseDataValue
from smscx_client.model.reports_summary_traffic_response import ReportsSummaryTrafficResponse
from smscx_client.model.reports_summary_traffic_response_data_value import ReportsSummaryTrafficResponseDataValue
from smscx_client.model.rich_media import RichMedia
from smscx_client.model.roaming_network import RoamingNetwork
from smscx_client.model.scheduled import Scheduled
from smscx_client.model.send_multichannel_campaign_request import SendMultichannelCampaignRequest
from smscx_client.model.send_multichannel_campaign_request_estimate import SendMultichannelCampaignRequestEstimate
from smscx_client.model.send_multichannel_campaign_response import SendMultichannelCampaignResponse
from smscx_client.model.send_multichannel_message_request import SendMultichannelMessageRequest
from smscx_client.model.send_multichannel_message_request_estimate import SendMultichannelMessageRequestEstimate
from smscx_client.model.send_multichannel_message_response import SendMultichannelMessageResponse
from smscx_client.model.send_sms_campaign_request import SendSmsCampaignRequest
from smscx_client.model.send_sms_campaign_request_estimate import SendSmsCampaignRequestEstimate
from smscx_client.model.send_sms_campaign_response import SendSmsCampaignResponse
from smscx_client.model.send_sms_message_request import SendSmsMessageRequest
from smscx_client.model.send_sms_message_response import SendSmsMessageResponse
from smscx_client.model.send_sms_request_estimate import SendSmsRequestEstimate
from smscx_client.model.send_viber_campaign_request import SendViberCampaignRequest
from smscx_client.model.send_viber_campaign_request_estimate import SendViberCampaignRequestEstimate
from smscx_client.model.send_viber_campaign_response import SendViberCampaignResponse
from smscx_client.model.send_viber_message_request import SendViberMessageRequest
from smscx_client.model.send_viber_message_request_estimate import SendViberMessageRequestEstimate
from smscx_client.model.send_viber_message_response import SendViberMessageResponse
from smscx_client.model.send_whatsapp_message_request import SendWhatsappMessageRequest
from smscx_client.model.send_whatsapp_message_request_estimate import SendWhatsappMessageRequestEstimate
from smscx_client.model.send_whatsapp_message_response import SendWhatsappMessageResponse
from smscx_client.model.settings import Settings
from smscx_client.model.shortlink_delete_response import ShortlinkDeleteResponse
from smscx_client.model.shortlink_details_response import ShortlinkDetailsResponse
from smscx_client.model.shortlink_new_request import ShortlinkNewRequest
from smscx_client.model.shortlink_new_response import ShortlinkNewResponse
from smscx_client.model.shortlink_update_request import ShortlinkUpdateRequest
from smscx_client.model.shortlink_update_response import ShortlinkUpdateResponse
from smscx_client.model.shortlinks import Shortlinks
from smscx_client.model.shortlinks_list_response import ShortlinksListResponse
from smscx_client.model.sms import Sms
from smscx_client.model.status import Status
from smscx_client.model.strategy import Strategy
from smscx_client.model.template_details_response import TemplateDetailsResponse
from smscx_client.model.templates_delete_response import TemplatesDeleteResponse
from smscx_client.model.templates_list_response import TemplatesListResponse
from smscx_client.model.templates_new_request import TemplatesNewRequest
from smscx_client.model.templates_new_response import TemplatesNewResponse
from smscx_client.model.templates_update_request import TemplatesUpdateRequest
from smscx_client.model.templates_update_response import TemplatesUpdateResponse
from smscx_client.model.text import Text
from smscx_client.model.text_analysis import TextAnalysis
from smscx_client.model.transliteration import Transliteration
from smscx_client.model.transliteration_analysis import TransliterationAnalysis
from smscx_client.model.transliteration_app_settings import TransliterationAppSettings
from smscx_client.model.two_way import TwoWay
from smscx_client.model.update_number_request import UpdateNumberRequest
from smscx_client.model.update_number_response import UpdateNumberResponse
from smscx_client.model.verify_pin_request import VerifyPinRequest
from smscx_client.model.verify_pin_response import VerifyPinResponse
from smscx_client.model.viber import Viber
from smscx_client.model.viber_whatsapp_pricing import ViberWhatsappPricing
from smscx_client.model.whatsapp import Whatsapp



import sys
import unittest

import smscx_client
from smscx_client.model.data_summary import DataSummary
globals()['DataSummary'] = DataSummary
from smscx_client.model.reports_summary_country_response_data_value import ReportsSummaryCountryResponseDataValue


class TestReportsSummaryCountryResponseDataValue(unittest.TestCase):
    """ReportsSummaryCountryResponseDataValue unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testReportsSummaryCountryResponseDataValue(self):
        """Test ReportsSummaryCountryResponseDataValue"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ReportsSummaryCountryResponseDataValue()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import sys
import unittest

import smscx_client
from smscx_client.model.data_rented_numbers import DataRentedNumbers
globals()['DataRentedNumbers'] = DataRentedNumbers
from smscx_client.model.rented_numbers_response import RentedNumbersResponse


class TestRentedNumbersResponse(unittest.TestCase):
    """RentedNumbersResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testRentedNumbersResponse(self):
        """Test RentedNumbersResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = RentedNumbersResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import unittest

import smscx_client
from smscx_client.api.groups_api import GroupsApi  # noqa: E501


class TestGroupsApi(unittest.TestCase):
    """GroupsApi unit test stubs"""

    def setUp(self):
        self.api = GroupsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_contacts_to_group(self):
        """Test case for add_contacts_to_group

        Add contacts to group  # noqa: E501
        """
        pass

    def test_create_group(self):
        """Test case for create_group

        Create new group  # noqa: E501
        """
        pass

    def test_delete_contact_from_group(self):
        """Test case for delete_contact_from_group

        Delete contact from group  # noqa: E501
        """
        pass

    def test_delete_group(self):
        """Test case for delete_group

        Delete group  # noqa: E501
        """
        pass

    def test_empty_group(self):
        """Test case for empty_group

        Empty group  # noqa: E501
        """
        pass

    def test_export_group_to_csv(self):
        """Test case for export_group_to_csv

        Export group to CSV  # noqa: E501
        """
        pass

    def test_export_group_to_xlsx(self):
        """Test case for export_group_to_xlsx

        Export group to XLSX  # noqa: E501
        """
        pass

    def test_get_group_details(self):
        """Test case for get_group_details

        Get group details  # noqa: E501
        """
        pass

    def test_get_groups_list(self):
        """Test case for get_groups_list

        Get list of groups  # noqa: E501
        """
        pass

    def test_update_contact_from_group(self):
        """Test case for update_contact_from_group

        Update contact from group  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



import re  # noqa: F401
import sys  # noqa: F401

from smscx_client.model_utils import (  # noqa: F401
    ApiTypeError,
    ModelComposed,
    ModelNormal,
    ModelSimple,
    cached_property,
    change_keys_js_to_python,
    convert_js_args_to_python_args,
    date,
    datetime,
    file_type,
    none_type,
    validate_get_composed_info,
    ApiModel
)
from smscx_client.exceptions import ApiAttributeError



class NewOtpResponse(ModelNormal):


    allowed_values = {
        ('status',): {
            'PENDING': "PENDING",
            'VERIFIED': "VERIFIED",
            'EXPIRED': "EXPIRED",
            'CANCELLED': "CANCELLED",
            'FAILED': "FAILED",
        },
    }

    validations = {
        ('otp_id',): {
            'max_length': 36,
            'min_length': 36,
            'regex': {
                'pattern': r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$',  # noqa: E501
            },
        },
        ('track_id',): {
            'max_length': 36,
            'min_length': 36,
            'regex': {
                'pattern': r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$',  # noqa: E501
            },
        },
        ('country_iso',): {
            'max_length': 2,
            'min_length': 2,
        },
        ('parts',): {
            'inclusive_minimum': 1,
        },
        ('max_attempts',): {
            'inclusive_maximum': 10,
            'inclusive_minimum': 1,
        },
        ('attempts',): {
            'inclusive_maximum': 10,
            'inclusive_minimum': 0,
        },
        ('ttl',): {
            'inclusive_maximum': 1800,
            'inclusive_minimum': 60,
        },
    }

    @cached_property
    def additional_properties_type():
        return (bool, date, datetime, dict, float, int, list, str, none_type,)  # noqa: E501

    _nullable = False

    @cached_property
    def api_types():
        """
        Returns
            api_types (dict): The key is attribute name
                and the value is attribute type.
        """
        return {
            'otp_id': (str,),  # noqa: E501
            'track_id': (str, none_type,),  # noqa: E501
            'phone_number': (str,),  # noqa: E501
            'country_iso': (str,),  # noqa: E501
            'status': (str,),  # noqa: E501
            'cost': (float,),  # noqa: E501
            'parts': (int,),  # noqa: E501
            'max_attempts': (int,),  # noqa: E501
            'attempts': (int,),  # noqa: E501
            'ttl': (int,),  # noqa: E501
            'otp_callback_url': (str, none_type,),  # noqa: E501
            'date_created': (datetime,),  # noqa: E501
            'date_expires': (datetime,),  # noqa: E501
        }

    @cached_property
    def discriminator():
        return None


    attribute_map = {
        'otp_id': 'otpId',  # noqa: E501
        'track_id': 'trackId',  # noqa: E501
        'phone_number': 'phoneNumber',  # noqa: E501
        'country_iso': 'countryIso',  # noqa: E501
        'status': 'status',  # noqa: E501
        'cost': 'cost',  # noqa: E501
        'parts': 'parts',  # noqa: E501
        'max_attempts': 'maxAttempts',  # noqa: E501
        'attempts': 'attempts',  # noqa: E501
        'ttl': 'ttl',  # noqa: E501
        'otp_callback_url': 'otpCallbackUrl',  # noqa: E501
        'date_created': 'dateCreated',  # noqa: E501
        'date_expires': 'dateExpires',  # noqa: E501
    }

    read_only_vars = {
    }

    _composed_schemas = {}

    @classmethod
    @convert_js_args_to_python_args
    def _from_api_data(cls, otp_id, track_id, phone_number, country_iso, status, cost, parts, max_attempts, attempts, ttl, otp_callback_url, date_created, date_expires, *args, **kwargs):  # noqa: E501
        """NewOtpResponse - a model

        Args:
            otp_id (str): Unique identifier of the OTP request
            track_id (str, none_type): Client provided UUID (v1-v5) for tracking purposes
            phone_number (str): The phone number where the pin was sent
            country_iso (str): The country ISO of the phone numver. Eg. `DE`, `FR`, `IT`
            status (str): Status of the OTP request. The initial status is `PENDING`
            cost (float): The cost of the OTP request
            parts (int): Message parts
            max_attempts (int): Number of attempts to allow the OTP to be verified before marking it as failed Note: If this parameter is set, it will overwrite the setting from [Admin Dashboard > HTTP API > Oauth2 > Application settings](#)
            attempts (int): Number of unsuccessful attempts made to validate the pin
            ttl (int): The time to live (ttl) defines the time in seconds that a pin is valid. Min 1 minute (60 seconds) and max 30 minutes (1800 seconds)  Note: If this parameter is set, it will overwrite the setting from [Admin Dashboard > HTTP API > Oauth2 > Application settings](#)
            otp_callback_url (str, none_type): The webhook where request will be made with status upddates for the OTP
            date_created (datetime): Datetime of the OTP request
            date_expires (datetime): Datetime of the OTP request expiration. After this date and time the pin will no longer be valid


        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', True)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        self = super(ApiModel, cls).__new__(cls)

        if args:
            for arg in args:
                if isinstance(arg, dict):
                    kwargs.update(arg)
                else:
                    raise ApiTypeError(
                        "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                            args,
                            self.__class__.__name__,
                        ),
                        path_to_item=_path_to_item,
                        valid_classes=(self.__class__,),
                    )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        self.otp_id = otp_id
        self.track_id = track_id
        self.phone_number = phone_number
        self.country_iso = country_iso
        self.status = status
        self.cost = cost
        self.parts = parts
        self.max_attempts = max_attempts
        self.attempts = attempts
        self.ttl = ttl
        self.otp_callback_url = otp_callback_url
        self.date_created = date_created
        self.date_expires = date_expires
        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
        return self

    required_properties = set([
        '_data_store',
        '_check_type',
        '_spec_property_naming',
        '_path_to_item',
        '_configuration',
        '_visited_composed_classes',
    ])

    @convert_js_args_to_python_args
    def __init__(self, otp_id, track_id, phone_number, country_iso, status, cost, parts, max_attempts, attempts, ttl, otp_callback_url, date_created, date_expires, *args, **kwargs):  # noqa: E501
        """NewOtpResponse - a model

        Args:
            otp_id (str): Unique identifier of the OTP request
            track_id (str, none_type): Client provided UUID (v1-v5) for tracking purposes
            phone_number (str): The phone number where the pin was sent
            country_iso (str): The country ISO of the phone numver. Eg. `DE`, `FR`, `IT`
            status (str): Status of the OTP request. The initial status is `PENDING`
            cost (float): The cost of the OTP request
            parts (int): Message parts
            max_attempts (int): Number of attempts to allow the OTP to be verified before marking it as failed Note: If this parameter is set, it will overwrite the setting from [Admin Dashboard > HTTP API > Oauth2 > Application settings](#)
            attempts (int): Number of unsuccessful attempts made to validate the pin
            ttl (int): The time to live (ttl) defines the time in seconds that a pin is valid. Min 1 minute (60 seconds) and max 30 minutes (1800 seconds)  Note: If this parameter is set, it will overwrite the setting from [Admin Dashboard > HTTP API > Oauth2 > Application settings](#)
            otp_callback_url (str, none_type): The webhook where request will be made with status upddates for the OTP
            date_created (datetime): Datetime of the OTP request
            date_expires (datetime): Datetime of the OTP request expiration. After this date and time the pin will no longer be valid


        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        if args:
            for arg in args:
                if isinstance(arg, dict):
                    kwargs.update(arg)
                else:
                    raise ApiTypeError(
                        "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                            args,
                            self.__class__.__name__,
                        ),
                        path_to_item=_path_to_item,
                        valid_classes=(self.__class__,),
                    )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        self.otp_id = otp_id
        self.track_id = track_id
        self.phone_number = phone_number
        self.country_iso = country_iso
        self.status = status
        self.cost = cost
        self.parts = parts
        self.max_attempts = max_attempts
        self.attempts = attempts
        self.ttl = ttl
        self.otp_callback_url = otp_callback_url
        self.date_created = date_created
        self.date_expires = date_expires
        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
            if var_name in self.read_only_vars:
                raise ApiAttributeError(f"`{var_name}` is a read-only attribute. Use `from_api_data` to instantiate "
                                     f"class with read only attributes.")



import re  # noqa: F401
import sys  # noqa: F401

from smscx_client.api_client import ApiClient, Endpoint as _Endpoint
from smscx_client.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from smscx_client.model.add_contacts_to_group400_response import AddContactsToGroup400Response
from smscx_client.model.add_contacts_to_group_request import AddContactsToGroupRequest
from smscx_client.model.add_contacts_to_group_response import AddContactsToGroupResponse
from smscx_client.model.delete_contact import DeleteContact
from smscx_client.model.delete_group import DeleteGroup
from smscx_client.model.group_details_response import GroupDetailsResponse
from smscx_client.model.group_response import GroupResponse
from smscx_client.model.groups_list import GroupsList
from smscx_client.model.model400_invalid_param import Model400InvalidParam
from smscx_client.model.model401_unauthorized import Model401Unauthorized
from smscx_client.model.model403_insufficient_scope import Model403InsufficientScope
from smscx_client.model.model403_no_coverage import Model403NoCoverage
from smscx_client.model.model404_not_found import Model404NotFound
from smscx_client.model.model500_server_error import Model500ServerError
from smscx_client.model.new_group_request import NewGroupRequest
from smscx_client.model.new_group_response import NewGroupResponse
from smscx_client.model.update_number_request import UpdateNumberRequest
from smscx_client.model.update_number_response import UpdateNumberResponse


class GroupsApi(object):
    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.add_contacts_to_group_endpoint = _Endpoint(
            settings={
                'response_type': (AddContactsToGroupResponse,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/groups/{groupId}',
                'operation_id': 'add_contacts_to_group',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'group_id',
                    'add_contacts_to_group_request',
                ],
                'required': [
                    'group_id',
                    'add_contacts_to_group_request',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'api_types': {
                    'group_id':
                        (int,),
                    'add_contacts_to_group_request':
                        (AddContactsToGroupRequest,),
                },
                'attribute_map': {
                    'group_id': 'groupId',
                },
                'location_map': {
                    'group_id': 'path',
                    'add_contacts_to_group_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.create_group_endpoint = _Endpoint(
            settings={
                'response_type': (NewGroupResponse,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/groups',
                'operation_id': 'create_group',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'new_group_request',
                ],
                'required': [
                    'new_group_request',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'api_types': {
                    'new_group_request':
                        (NewGroupRequest,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'new_group_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.delete_contact_from_group_endpoint = _Endpoint(
            settings={
                'response_type': (DeleteContact,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/groups/{groupId}/{phoneNumberId}',
                'operation_id': 'delete_contact_from_group',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'group_id',
                    'phone_number_id',
                ],
                'required': [
                    'group_id',
                    'phone_number_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'phone_number_id',
                ]
            },
            root_map={
                'validations': {
                    ('phone_number_id',): {
                        'max_length': 36,
                        'min_length': 36,
                        'regex': {
                            'pattern': r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$',  # noqa: E501
                        },
                    },
                },
                'allowed_values': {
                },
                'api_types': {
                    'group_id':
                        (int,),
                    'phone_number_id':
                        (str,),
                },
                'attribute_map': {
                    'group_id': 'groupId',
                    'phone_number_id': 'phoneNumberId',
                },
                'location_map': {
                    'group_id': 'path',
                    'phone_number_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.delete_group_endpoint = _Endpoint(
            settings={
                'response_type': (DeleteGroup,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/groups/{groupId}',
                'operation_id': 'delete_group',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'group_id',
                ],
                'required': [
                    'group_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'api_types': {
                    'group_id':
                        (int,),
                },
                'attribute_map': {
                    'group_id': 'groupId',
                },
                'location_map': {
                    'group_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.empty_group_endpoint = _Endpoint(
            settings={
                'response_type': (GroupResponse,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/groups/{groupId}/empty',
                'operation_id': 'empty_group',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'group_id',
                ],
                'required': [
                    'group_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'api_types': {
                    'group_id':
                        (int,),
                },
                'attribute_map': {
                    'group_id': 'groupId',
                },
                'location_map': {
                    'group_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.export_group_to_csv_endpoint = _Endpoint(
            settings={
                'response_type': (str,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/groups/{groupId}/csv',
                'operation_id': 'export_group_to_csv',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'group_id',
                ],
                'required': [
                    'group_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'api_types': {
                    'group_id':
                        (int,),
                },
                'attribute_map': {
                    'group_id': 'groupId',
                },
                'location_map': {
                    'group_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/csv',
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.export_group_to_xlsx_endpoint = _Endpoint(
            settings={
                'response_type': (file_type,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/groups/{groupId}/xlsx',
                'operation_id': 'export_group_to_xlsx',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'group_id',
                ],
                'required': [
                    'group_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'api_types': {
                    'group_id':
                        (int,),
                },
                'attribute_map': {
                    'group_id': 'groupId',
                },
                'location_map': {
                    'group_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet',
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_group_details_endpoint = _Endpoint(
            settings={
                'response_type': (GroupDetailsResponse,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/groups/{groupId}',
                'operation_id': 'get_group_details',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'group_id',
                    'short_response',
                    'limit',
                    'next',
                    'previous',
                ],
                'required': [
                    'group_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'api_types': {
                    'group_id':
                        (int,),
                    'short_response':
                        (bool,),
                    'limit':
                        (int,),
                    'next':
                        (str,),
                    'previous':
                        (str,),
                },
                'attribute_map': {
                    'group_id': 'groupId',
                    'short_response': 'short_response',
                    'limit': 'limit',
                    'next': 'next',
                    'previous': 'previous',
                },
                'location_map': {
                    'group_id': 'path',
                    'short_response': 'query',
                    'limit': 'query',
                    'next': 'query',
                    'previous': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_groups_list_endpoint = _Endpoint(
            settings={
                'response_type': (GroupsList,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/groups',
                'operation_id': 'get_groups_list',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'api_types': {
                },
                'attribute_map': {
                },
                'location_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.update_contact_from_group_endpoint = _Endpoint(
            settings={
                'response_type': (UpdateNumberResponse,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/groups/{groupId}/{phoneNumberId}',
                'operation_id': 'update_contact_from_group',
                'http_method': 'PATCH',
                'servers': None,
            },
            params_map={
                'all': [
                    'group_id',
                    'phone_number_id',
                    'update_number_request',
                ],
                'required': [
                    'group_id',
                    'phone_number_id',
                    'update_number_request',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'phone_number_id',
                ]
            },
            root_map={
                'validations': {
                    ('phone_number_id',): {
                        'max_length': 36,
                        'min_length': 36,
                        'regex': {
                            'pattern': r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$',  # noqa: E501
                        },
                    },
                },
                'allowed_values': {
                },
                'api_types': {
                    'group_id':
                        (int,),
                    'phone_number_id':
                        (str,),
                    'update_number_request':
                        (UpdateNumberRequest,),
                },
                'attribute_map': {
                    'group_id': 'groupId',
                    'phone_number_id': 'phoneNumberId',
                },
                'location_map': {
                    'group_id': 'path',
                    'phone_number_id': 'path',
                    'update_number_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )

    def add_contacts_to_group(
        self,
        group_id,
        add_contacts_to_group_request,
        **kwargs
    ):
        """Add contacts to group  # noqa: E501

        Add contacts to a group if a valid identifier was provided.    
### Errors for POST `/groups/{groupId}`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
|  400 | 1203  |  invalid_param  | The parameter `phoneNumbers` is empty or not set |  

|  400 | 1208  |  invalid_param  |  The parameter `phoneNumbers` must be an array of phone numbers  |    

|  400 | 1207  |  invalid_param  | The phone number provided is not valid |  

|  400 | 1210  |  invalid_param  | The phone numbers provided are invalid |  
|  404 | 1200  |  not_found  | Group ID not found |  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.add_contacts_to_group(group_id, add_contacts_to_group_request, async_req=True)
        >>> result = thread.get()

        Args:
            group_id (int): Identifier of a group of contacts
            add_contacts_to_group_request (AddContactsToGroupRequest): 

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            AddContactsToGroupResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['group_id'] = \
            group_id
        kwargs['add_contacts_to_group_request'] = \
            add_contacts_to_group_request
        return self.add_contacts_to_group_endpoint.call_with_http_info(**kwargs)

    def create_group(
        self,
        new_group_request,
        **kwargs
    ):
        """Create new group  # noqa: E501

        Creates a new group.      
### Errors for POST `/groups`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
|  400 | 1204  |  invalid_param  | The name is empty or parameter `name` not set |  

|  400 | 1206  |  invalid_param  | The name provided is invalid (min 3, max 60 characters) |  

|  400 | 1211  |  duplicate_value  | You already have a group with this name |  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_group(new_group_request, async_req=True)
        >>> result = thread.get()

        Args:
            new_group_request (NewGroupRequest): 

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            NewGroupResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['new_group_request'] = \
            new_group_request
        return self.create_group_endpoint.call_with_http_info(**kwargs)

    def delete_contact_from_group(
        self,
        group_id,
        phone_number_id,
        **kwargs
    ):
        """Delete contact from group  # noqa: E501

        Deletes a contact from a group if a valid group identifier was provided.    
### Errors for DELETE `/groups/{groupId}/{phoneNumberId}`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
|  404 | 1200  |  not_found  | Group ID not found |  
|  404 | 1202  |  not_found  | Phone number ID not found |  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_contact_from_group(group_id, phone_number_id, async_req=True)
        >>> result = thread.get()

        Args:
            group_id (int): Identifier of a group of contacts
            phone_number_id (str): Identifier of the phone number

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            DeleteContact
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['group_id'] = \
            group_id
        kwargs['phone_number_id'] = \
            phone_number_id
        return self.delete_contact_from_group_endpoint.call_with_http_info(**kwargs)

    def delete_group(
        self,
        group_id,
        **kwargs
    ):
        """Delete group  # noqa: E501

        Deletes a group and all the contacts in the group    
### Errors for DELETE `/groups/{groupId}`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
|  404 | 1200  |  not_found  | Group ID not found |  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_group(group_id, async_req=True)
        >>> result = thread.get()

        Args:
            group_id (int): Identifier of a group of contacts

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            DeleteGroup
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['group_id'] = \
            group_id
        return self.delete_group_endpoint.call_with_http_info(**kwargs)

    def empty_group(
        self,
        group_id,
        **kwargs
    ):
        """Empty group  # noqa: E501

        Deletes all the contacts in a group.        Returns HTTP `204 No content` if group is already empty.    
### Errors for GET `/groups/{groupId}/empty`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
|  404 | 1200  |  not_found  | Group ID not found |  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.empty_group(group_id, async_req=True)
        >>> result = thread.get()

        Args:
            group_id (int): Identifier of a group of contacts

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            GroupResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['group_id'] = \
            group_id
        return self.empty_group_endpoint.call_with_http_info(**kwargs)

    def export_group_to_csv(
        self,
        group_id,
        **kwargs
    ):
        """Export group to CSV  # noqa: E501

        Exports the contacts from a group to a CSV file.    If the group is empty, an empty CSV file is returned (with first line headers).    
### Errors for GET `/groups/{groupId}/csv`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
|  404 | 1200  |  not_found  | Group ID not found |  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.export_group_to_csv(group_id, async_req=True)
        >>> result = thread.get()

        Args:
            group_id (int): Identifier of a group of contacts

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            str
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['group_id'] = \
            group_id
        return self.export_group_to_csv_endpoint.call_with_http_info(**kwargs)

    def export_group_to_xlsx(
        self,
        group_id,
        **kwargs
    ):
        """Export group to XLSX  # noqa: E501

        Exports the contacts from a group to a XLSX file (Excel).    If the group is empty, an empty XLSX file is returned (with first line headers).    
### Errors for GET `/groups/{groupId}/xlsx`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
|  404 | 1200  |  not_found  | Group ID not found |  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.export_group_to_xlsx(group_id, async_req=True)
        >>> result = thread.get()

        Args:
            group_id (int): Identifier of a group of contacts

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            file_type
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['group_id'] = \
            group_id
        return self.export_group_to_xlsx_endpoint.call_with_http_info(**kwargs)

    def get_group_details(
        self,
        group_id,
        **kwargs
    ):
        """Get group details  # noqa: E501

        Retrieves the details of a group if a valid identifier was provided.      
### Errors for GET `/groups/{groupId}`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
|  404 | 1200  |  not_found  | Group ID not found |  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_group_details(group_id, async_req=True)
        >>> result = thread.get()

        Args:
            group_id (int): Identifier of a group of contacts

        Keyword Args:
            short_response (bool): If set to true, it will return the full `info` object and an empty `data` object. [optional] if omitted the server will use the default value of False
            limit (int): A limit on the number of objects to be returned. [optional] if omitted the server will use the default value of 500
            next (str): The next token used to retrieve additional data. [optional]
            previous (str): The previous token used to retrieve additional data. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            GroupDetailsResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['group_id'] = \
            group_id
        return self.get_group_details_endpoint.call_with_http_info(**kwargs)

    def get_groups_list(
        self,
        **kwargs
    ):
        """Get list of groups  # noqa: E501

        Retrieves the list of existing groups of contacts. The groups are returned sorted by creation date, with the most recent group appearing first.    If no groups are available, an empty data object is returned.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_groups_list(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            GroupsList
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.get_groups_list_endpoint.call_with_http_info(**kwargs)

    def update_contact_from_group(
        self,
        group_id,
        phone_number_id,
        update_number_request,
        **kwargs
    ):
        """Update contact from group  # noqa: E501

        Updates the specified contact by setting the values of the parameters passed. Any parameters not provided will be left unchanged.    Returns HTTP `204 No content` if the parameters provided did not update the contact because the data was already the same.    
### Errors for PATCH `/groups/{groupId}/{phoneNumberId}`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
|  404 | 1202  |  not_found  | Phone number ID not found |  

|  400 | 1213  |  invalid_param  | At least one parameter required (phoneNumber, firstName, lastName, email, field1, field2, field3, field4, field5, customFields) |  

|  400 | 1215  |  duplicate_value  | The phone number already exists |  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_contact_from_group(group_id, phone_number_id, update_number_request, async_req=True)
        >>> result = thread.get()

        Args:
            group_id (int): Identifier of a group of contacts
            phone_number_id (str): Identifier of the phone number
            update_number_request (UpdateNumberRequest): 

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            UpdateNumberResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['group_id'] = \
            group_id
        kwargs['phone_number_id'] = \
            phone_number_id
        kwargs['update_number_request'] = \
            update_number_request
        return self.update_contact_from_group_endpoint.call_with_http_info(**kwargs)




import sys
import unittest

import smscx_client
from smscx_client.model.data_templates_list import DataTemplatesList
globals()['DataTemplatesList'] = DataTemplatesList
from smscx_client.model.templates_list_response import TemplatesListResponse


class TestTemplatesListResponse(unittest.TestCase):
    """TemplatesListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testTemplatesListResponse(self):
        """Test TemplatesListResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = TemplatesListResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import sys
import unittest

import smscx_client
from smscx_client.model.original_text import OriginalText
from smscx_client.model.replaced_text import ReplacedText
globals()['OriginalText'] = OriginalText
globals()['ReplacedText'] = ReplacedText
from smscx_client.model.text import Text


class TestText(unittest.TestCase):
    """Text unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testText(self):
        """Test Text"""
        # FIXME: construct object with mandatory attributes with example values
        # model = Text()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# flake8: noqa

__version__ = "0.1.0"

# import ApiClient
from smscx_client.api_client import ApiClient

# import Configuration
from smscx_client.configuration import Configuration

# import exceptions
from smscx_client.exceptions import ApiExceptionBase
from smscx_client.exceptions import ApiAttributeError
from smscx_client.exceptions import ApiTypeError
from smscx_client.exceptions import ApiValueError
from smscx_client.exceptions import ApiKeyError
from smscx_client.exceptions import ApiException
from smscx_client.exceptions import InsufficientBalanceException, DuplicateIdException, DuplicateValueException, OtpAlreadyVerifiedException, OtpCancelledException, OtpExpiredException, OtpFailedException, InvalidPinException, InvalidPhoneNumberException, InvalidScopeException, InvalidRequestException, InvalidCredentialsException, InsufficientScopeException, NoCoverageException, TemplateNotApprovedException, ChannelNotActiveException, OtpCancelledException, OtpActionNotAllowedException, AccessDeniedException, ResourceNotFoundException, ApiMethodNotAllowedException, RateLimitExcedeedException, ServerErrorException




import sys
import unittest

import smscx_client
from smscx_client.model.pricing_sms_response import PricingSmsResponse
from smscx_client.model.pricing_viber_whatsapp_response import PricingViberWhatsappResponse
from smscx_client.model.viber_whatsapp_pricing import ViberWhatsappPricing
globals()['PricingSmsResponse'] = PricingSmsResponse
globals()['PricingViberWhatsappResponse'] = PricingViberWhatsappResponse
globals()['ViberWhatsappPricing'] = ViberWhatsappPricing
from smscx_client.model.get_channel_pricing200_response import GetChannelPricing200Response


class TestGetChannelPricing200Response(unittest.TestCase):
    """GetChannelPricing200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetChannelPricing200Response(self):
        """Test GetChannelPricing200Response"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetChannelPricing200Response()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import re  # noqa: F401
import sys  # noqa: F401

from smscx_client.api_client import ApiClient, Endpoint as _Endpoint
from smscx_client.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from smscx_client.model.model400_invalid_param import Model400InvalidParam
from smscx_client.model.model401_unauthorized import Model401Unauthorized
from smscx_client.model.model403_insufficient_scope import Model403InsufficientScope
from smscx_client.model.model404_not_found import Model404NotFound
from smscx_client.model.model500_server_error import Model500ServerError
from smscx_client.model.originator_new_request import OriginatorNewRequest
from smscx_client.model.originator_new_response import OriginatorNewResponse
from smscx_client.model.originators_list_response import OriginatorsListResponse


class OriginatorsApi(object):
    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.create_originator_endpoint = _Endpoint(
            settings={
                'response_type': (OriginatorNewResponse,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/originators',
                'operation_id': 'create_originator',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'originator_new_request',
                ],
                'required': [
                    'originator_new_request',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'api_types': {
                    'originator_new_request':
                        (OriginatorNewRequest,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'originator_new_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.delete_originator_endpoint = _Endpoint(
            settings={
                'response_type': (OriginatorNewResponse,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/originators/{originatorId}',
                'operation_id': 'delete_originator',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'originator_id',
                ],
                'required': [
                    'originator_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'api_types': {
                    'originator_id':
                        (int,),
                },
                'attribute_map': {
                    'originator_id': 'originatorId',
                },
                'location_map': {
                    'originator_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_originators_list_endpoint = _Endpoint(
            settings={
                'response_type': (OriginatorsListResponse,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/originators',
                'operation_id': 'get_originators_list',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'api_types': {
                },
                'attribute_map': {
                },
                'location_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

    def create_originator(
        self,
        originator_new_request,
        **kwargs
    ):
        """Create new originator  # noqa: E501

        Creates and submits an originator for approval.    
### Errors for POST `/originators`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
|  400 | 1301  |  invalid_param  |  The originator is empty or parameter `originator` not set |  

|  400 | 1303  |  invalid_param  |  The parameter `originator` can contain only letters and numbers |  

|  400 | 1304  |  invalid_param  |  The alphanumeric originator provided is invalid (min 3, max 11 characters) |  

|  400 | 1305  |  invalid_param  |  The numeric originator provided is invalid (min 3, max 15 characters) |  

|  400 | 1306  |  duplicate_value  |  Originator already exists |  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_originator(originator_new_request, async_req=True)
        >>> result = thread.get()

        Args:
            originator_new_request (OriginatorNewRequest): 

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            OriginatorNewResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['originator_new_request'] = \
            originator_new_request
        return self.create_originator_endpoint.call_with_http_info(**kwargs)

    def delete_originator(
        self,
        originator_id,
        **kwargs
    ):
        """Delete originator  # noqa: E501

        Deletes an originator if a valid identifier was provided.    
### Errors for DELETE `/originators/{originatorId}`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
|  404 | 1300  |  not_found  |  Originator ID not found  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_originator(originator_id, async_req=True)
        >>> result = thread.get()

        Args:
            originator_id (int): Identifier of the originator

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            OriginatorNewResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['originator_id'] = \
            originator_id
        return self.delete_originator_endpoint.call_with_http_info(**kwargs)

    def get_originators_list(
        self,
        **kwargs
    ):
        """Get originators list  # noqa: E501

        Retrieves the list of existing originators (sender ids). The originators are returned sorted by creation date, with the most recent group appearing first.    If no originators are available, an empty data object is returned  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_originators_list(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            OriginatorsListResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.get_originators_list_endpoint.call_with_http_info(**kwargs)




import sys
import unittest

import smscx_client
from smscx_client.model.info_rent_number import InfoRentNumber
globals()['InfoRentNumber'] = InfoRentNumber
from smscx_client.model.get_rent_status_response import GetRentStatusResponse


class TestGetRentStatusResponse(unittest.TestCase):
    """GetRentStatusResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetRentStatusResponse(self):
        """Test GetRentStatusResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetRentStatusResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import sys
import unittest

import smscx_client
from smscx_client.model.country_price_obj1 import CountryPriceObj1


class TestCountryPriceObj1(unittest.TestCase):
    """CountryPriceObj1 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCountryPriceObj1(self):
        """Test CountryPriceObj1"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CountryPriceObj1()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import sys
import unittest

import smscx_client
from smscx_client.model.data_originators_list import DataOriginatorsList
globals()['DataOriginatorsList'] = DataOriginatorsList
from smscx_client.model.originators_list_response import OriginatorsListResponse


class TestOriginatorsListResponse(unittest.TestCase):
    """OriginatorsListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testOriginatorsListResponse(self):
        """Test OriginatorsListResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = OriginatorsListResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import sys
import unittest

import smscx_client
from smscx_client.model.custom_fields import CustomFields
globals()['CustomFields'] = CustomFields
from smscx_client.model.send_viber_campaign_request import SendViberCampaignRequest


class TestSendViberCampaignRequest(unittest.TestCase):
    """SendViberCampaignRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSendViberCampaignRequest(self):
        """Test SendViberCampaignRequest"""
        # FIXME: construct object with mandatory attributes with example values
        # model = SendViberCampaignRequest()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import sys
import unittest

import smscx_client
from smscx_client.model.info_phone_number_update import InfoPhoneNumberUpdate
globals()['InfoPhoneNumberUpdate'] = InfoPhoneNumberUpdate
from smscx_client.model.update_number_response import UpdateNumberResponse


class TestUpdateNumberResponse(unittest.TestCase):
    """UpdateNumberResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testUpdateNumberResponse(self):
        """Test UpdateNumberResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = UpdateNumberResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import sys
import unittest

import smscx_client
from smscx_client.model.quiet_hours import QuietHours
globals()['QuietHours'] = QuietHours
from smscx_client.model.multichannel import Multichannel


class TestMultichannel(unittest.TestCase):
    """Multichannel unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testMultichannel(self):
        """Test Multichannel"""
        # FIXME: construct object with mandatory attributes with example values
        # model = Multichannel()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import sys
import unittest

import smscx_client
from smscx_client.model.data_viber import DataViber
from smscx_client.model.info_conversation_reply import InfoConversationReply
globals()['DataViber'] = DataViber
globals()['InfoConversationReply'] = InfoConversationReply
from smscx_client.model.conversation_reply_whatsapp_response import ConversationReplyWhatsappResponse


class TestConversationReplyWhatsappResponse(unittest.TestCase):
    """ConversationReplyWhatsappResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testConversationReplyWhatsappResponse(self):
        """Test ConversationReplyWhatsappResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ConversationReplyWhatsappResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import re  # noqa: F401
import sys  # noqa: F401

from smscx_client.model_utils import (  # noqa: F401
    ApiTypeError,
    ModelComposed,
    ModelNormal,
    ModelSimple,
    cached_property,
    change_keys_js_to_python,
    convert_js_args_to_python_args,
    date,
    datetime,
    file_type,
    none_type,
    validate_get_composed_info,
    ApiModel
)
from smscx_client.exceptions import ApiAttributeError



class NewOtpRequest(ModelNormal):


    allowed_values = {
        ('pin_type',): {
            'LETTERS': "letters",
            'NUMBERS': "numbers",
            'ALPHANUMERIC': "alphanumeric",
        },
    }

    validations = {
        ('country_iso',): {
            'max_length': 2,
            'min_length': 2,
        },
        ('_from',): {
            'max_length': 15,
            'min_length': 3,
        },
        ('track_id',): {
            'max_length': 36,
            'min_length': 36,
            'regex': {
                'pattern': r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$',  # noqa: E501
            },
        },
        ('ttl',): {
            'inclusive_maximum': 1800,
            'inclusive_minimum': 60,
        },
        ('max_attempts',): {
            'inclusive_maximum': 10,
            'inclusive_minimum': 1,
        },
        ('pin_length',): {
            'inclusive_maximum': 10,
            'inclusive_minimum': 4,
        },
    }

    @cached_property
    def additional_properties_type():
        return (bool, date, datetime, dict, float, int, list, str, none_type,)  # noqa: E501

    _nullable = False

    @cached_property
    def api_types():
        """
        Returns
            api_types (dict): The key is attribute name
                and the value is attribute type.
        """
        return {
            'phone_number': (str,),  # noqa: E501
            'country_iso': (str,),  # noqa: E501
            '_from': (str,),  # noqa: E501
            'template': (str,),  # noqa: E501
            'track_id': (str,),  # noqa: E501
            'ttl': (int,),  # noqa: E501
            'max_attempts': (int,),  # noqa: E501
            'pin_type': (str,),  # noqa: E501
            'pin_length': (int,),  # noqa: E501
            'otp_callback_url': (str,),  # noqa: E501
        }

    @cached_property
    def discriminator():
        return None


    attribute_map = {
        'phone_number': 'phoneNumber',  # noqa: E501
        'country_iso': 'countryIso',  # noqa: E501
        '_from': 'from',  # noqa: E501
        'template': 'template',  # noqa: E501
        'track_id': 'trackId',  # noqa: E501
        'ttl': 'ttl',  # noqa: E501
        'max_attempts': 'maxAttempts',  # noqa: E501
        'pin_type': 'pinType',  # noqa: E501
        'pin_length': 'pinLength',  # noqa: E501
        'otp_callback_url': 'otpCallbackUrl',  # noqa: E501
    }

    read_only_vars = {
    }

    _composed_schemas = {}

    @classmethod
    @convert_js_args_to_python_args
    def _from_api_data(cls, phone_number, *args, **kwargs):  # noqa: E501
        """NewOtpRequest - a model

        Args:
            phone_number (str): Phone number in international E.164 format or national format. If national format is provided, for better validation you must use the parameter `countryIso` to provide the country code of the destination phone number    


            country_iso (str): Country ISO (two-letter) of the destination phone numbers (if provided in national format). Please note that if an international E.164 phone number format is provided in the `to` parameter, the **countryIso** will be ignored. Eg. **FR** for France, **GB** for United Kingdom. Note: It is \"GB\", not \"UK\", as per the ISO-3166 alpha 2. [optional]  # noqa: E501
            _from (str): The originator (sender name) of the text message (min 3, max 11 characters). If the originator used in this value is not approved, it will be overwritten by a default system originator (eg. InfoText). Read more about [sender names](#) Note: This parameter is optional and can be used only if you want to overwrite the OTP settings of your SMS API application. [optional]  # noqa: E501
            template (str): The text message that will be delivered to the mobile number. It must contain the placeholder `{{pin}}`.    Note: This parameter is optional and can be used only if you want to overwrite the OTP settings of your SMS API application. [General placeholders](#) can be used in the text template.. [optional]  # noqa: E501
            track_id (str): Client provided UUID (v1-v5) for tracking purposes. [optional]  # noqa: E501
            ttl (int): The time to live (ttl) defines the time in seconds that a pin is valid. Min 1 minute (60 seconds) and max 30 minutes (1800 seconds)   Note: If this parameter is set, it will overwrite the setting from [Admin Dashboard > HTTP API > Oauth2 > Application settings](#). [optional]  # noqa: E501
            max_attempts (int): Number of attempts to allow the OTP to be verified before marking it as failed  Note: If this parameter is set, it will overwrite the setting from [Admin Dashboard > HTTP API > Oauth2 > Application settings](#). [optional]  # noqa: E501
            pin_type (str): Type of pin that will be generated for each mobile phone and will replace the placeholder {{pin}  Note: If this parameter is set, it will overwrite the setting from [Admin Dashboard > HTTP API > Oauth2 > Application settings](#). [optional]  # noqa: E501
            pin_length (int): Character length of the pin   Note: If this parameter is set, it will overwrite the setting from [Admin Dashboard > HTTP API > Oauth2 > Application settings](#). [optional]  # noqa: E501
            otp_callback_url (str): A valid URL to receive status updates for the OTP verification.   Note: If this parameter is set, it will overwrite the setting from [Admin Dashboard > HTTP API > Oauth2 > Application settings](#). [optional]  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', True)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        self = super(ApiModel, cls).__new__(cls)

        if args:
            for arg in args:
                if isinstance(arg, dict):
                    kwargs.update(arg)
                else:
                    raise ApiTypeError(
                        "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                            args,
                            self.__class__.__name__,
                        ),
                        path_to_item=_path_to_item,
                        valid_classes=(self.__class__,),
                    )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        self.phone_number = phone_number
        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
        return self

    required_properties = set([
        '_data_store',
        '_check_type',
        '_spec_property_naming',
        '_path_to_item',
        '_configuration',
        '_visited_composed_classes',
    ])

    @convert_js_args_to_python_args
    def __init__(self, phone_number, *args, **kwargs):  # noqa: E501
        """NewOtpRequest - a model

        Args:
            phone_number (str): Phone number in international E.164 format or national format. If national format is provided, for better validation you must use the parameter `countryIso` to provide the country code of the destination phone number    


            country_iso (str): Country ISO (two-letter) of the destination phone numbers (if provided in national format). Please note that if an international E.164 phone number format is provided in the `to` parameter, the **countryIso** will be ignored. Eg. **FR** for France, **GB** for United Kingdom. Note: It is \"GB\", not \"UK\", as per the ISO-3166 alpha 2. [optional]  # noqa: E501
            _from (str): The originator (sender name) of the text message (min 3, max 11 characters). If the originator used in this value is not approved, it will be overwritten by a default system originator (eg. InfoText). Read more about [sender names](#) Note: This parameter is optional and can be used only if you want to overwrite the OTP settings of your SMS API application. [optional]  # noqa: E501
            template (str): The text message that will be delivered to the mobile number. It must contain the placeholder `{{pin}}`.    Note: This parameter is optional and can be used only if you want to overwrite the OTP settings of your SMS API application. [General placeholders](#) can be used in the text template.. [optional]  # noqa: E501
            track_id (str): Client provided UUID (v1-v5) for tracking purposes. [optional]  # noqa: E501
            ttl (int): The time to live (ttl) defines the time in seconds that a pin is valid. Min 1 minute (60 seconds) and max 30 minutes (1800 seconds)   Note: If this parameter is set, it will overwrite the setting from [Admin Dashboard > HTTP API > Oauth2 > Application settings](#). [optional]  # noqa: E501
            max_attempts (int): Number of attempts to allow the OTP to be verified before marking it as failed  Note: If this parameter is set, it will overwrite the setting from [Admin Dashboard > HTTP API > Oauth2 > Application settings](#). [optional]  # noqa: E501
            pin_type (str): Type of pin that will be generated for each mobile phone and will replace the placeholder {{pin}  Note: If this parameter is set, it will overwrite the setting from [Admin Dashboard > HTTP API > Oauth2 > Application settings](#). [optional]  # noqa: E501
            pin_length (int): Character length of the pin   Note: If this parameter is set, it will overwrite the setting from [Admin Dashboard > HTTP API > Oauth2 > Application settings](#). [optional]  # noqa: E501
            otp_callback_url (str): A valid URL to receive status updates for the OTP verification.   Note: If this parameter is set, it will overwrite the setting from [Admin Dashboard > HTTP API > Oauth2 > Application settings](#). [optional]  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        if args:
            for arg in args:
                if isinstance(arg, dict):
                    kwargs.update(arg)
                else:
                    raise ApiTypeError(
                        "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                            args,
                            self.__class__.__name__,
                        ),
                        path_to_item=_path_to_item,
                        valid_classes=(self.__class__,),
                    )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        self.phone_number = phone_number
        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
            if var_name in self.read_only_vars:
                raise ApiAttributeError(f"`{var_name}` is a read-only attribute. Use `from_api_data` to instantiate "
                                     f"class with read only attributes.")



import re  # noqa: F401
import sys  # noqa: F401

from smscx_client.model_utils import (  # noqa: F401
    ApiTypeError,
    ModelComposed,
    ModelNormal,
    ModelSimple,
    cached_property,
    change_keys_js_to_python,
    convert_js_args_to_python_args,
    date,
    datetime,
    file_type,
    none_type,
    validate_get_composed_info,
    ApiModel
)
from smscx_client.exceptions import ApiAttributeError


def lazy_import():
    from smscx_client.model.characters_replaced import CharactersReplaced
    globals()['CharactersReplaced'] = CharactersReplaced


class ReplacedText(ModelNormal):


    allowed_values = {
        ('encoding',): {
            'GSM-7': "GSM-7",
            'UCS-2': "UCS-2",
        },
    }

    validations = {
    }

    additional_properties_type = None

    _nullable = False

    @cached_property
    def api_types():
        """
        Returns
            api_types (dict): The key is attribute name
                and the value is attribute type.
        """
        lazy_import()
        return {
            'text': (str,),  # noqa: E501
            'length': (int,),  # noqa: E501
            'parts': (int,),  # noqa: E501
            'encoding': (str,),  # noqa: E501
            'characters': (CharactersReplaced,),  # noqa: E501
        }

    @cached_property
    def discriminator():
        return None


    attribute_map = {
        'text': 'text',  # noqa: E501
        'length': 'length',  # noqa: E501
        'parts': 'parts',  # noqa: E501
        'encoding': 'encoding',  # noqa: E501
        'characters': 'characters',  # noqa: E501
    }

    read_only_vars = {
    }

    _composed_schemas = {}

    @classmethod
    @convert_js_args_to_python_args
    def _from_api_data(cls, text, length, parts, encoding, characters, *args, **kwargs):  # noqa: E501
        """ReplacedText - a model

        Args:
            text (str): Text after the conversion of Unicode characters to GSM alphabet
            length (int): Length of the converted text
            parts (int): Message parts
            encoding (str): Encoding of the converted text
            characters (CharactersReplaced):


                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', True)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        self = super(ApiModel, cls).__new__(cls)

        if args:
            for arg in args:
                if isinstance(arg, dict):
                    kwargs.update(arg)
                else:
                    raise ApiTypeError(
                        "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                            args,
                            self.__class__.__name__,
                        ),
                        path_to_item=_path_to_item,
                        valid_classes=(self.__class__,),
                    )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        self.text = text
        self.length = length
        self.parts = parts
        self.encoding = encoding
        self.characters = characters
        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
        return self

    required_properties = set([
        '_data_store',
        '_check_type',
        '_spec_property_naming',
        '_path_to_item',
        '_configuration',
        '_visited_composed_classes',
    ])

    @convert_js_args_to_python_args
    def __init__(self, text, length, parts, encoding, characters, *args, **kwargs):  # noqa: E501
        """ReplacedText - a model

        Args:
            text (str): Text after the conversion of Unicode characters to GSM alphabet
            length (int): Length of the converted text
            parts (int): Message parts
            encoding (str): Encoding of the converted text
            characters (CharactersReplaced):


                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        if args:
            for arg in args:
                if isinstance(arg, dict):
                    kwargs.update(arg)
                else:
                    raise ApiTypeError(
                        "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                            args,
                            self.__class__.__name__,
                        ),
                        path_to_item=_path_to_item,
                        valid_classes=(self.__class__,),
                    )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        self.text = text
        self.length = length
        self.parts = parts
        self.encoding = encoding
        self.characters = characters
        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
            if var_name in self.read_only_vars:
                raise ApiAttributeError(f"`{var_name}` is a read-only attribute. Use `from_api_data` to instantiate "
                                     f"class with read only attributes.")



import sys
import unittest

import smscx_client
from smscx_client.model.data_conversation import DataConversation
from smscx_client.model.info_conversation import InfoConversation
globals()['DataConversation'] = DataConversation
globals()['InfoConversation'] = InfoConversation
from smscx_client.model.conversation_details_response import ConversationDetailsResponse


class TestConversationDetailsResponse(unittest.TestCase):
    """ConversationDetailsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testConversationDetailsResponse(self):
        """Test ConversationDetailsResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ConversationDetailsResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import sys
import unittest

import smscx_client
from smscx_client.model.data_optouts import DataOptouts
from smscx_client.model.info_optouts import InfoOptouts
from smscx_client.model.paging import Paging
globals()['DataOptouts'] = DataOptouts
globals()['InfoOptouts'] = InfoOptouts
globals()['Paging'] = Paging
from smscx_client.model.optouts_list_response import OptoutsListResponse


class TestOptoutsListResponse(unittest.TestCase):
    """OptoutsListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testOptoutsListResponse(self):
        """Test OptoutsListResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = OptoutsListResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import sys
import unittest

import smscx_client
from smscx_client.model.group import Group
from smscx_client.model.phone_numbers_by_country import PhoneNumbersByCountry
from smscx_client.model.transliteration_analysis import TransliterationAnalysis
globals()['Group'] = Group
globals()['PhoneNumbersByCountry'] = PhoneNumbersByCountry
globals()['TransliterationAnalysis'] = TransliterationAnalysis
from smscx_client.model.info_campaign import InfoCampaign


class TestInfoCampaign(unittest.TestCase):
    """InfoCampaign unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testInfoCampaign(self):
        """Test InfoCampaign"""
        # FIXME: construct object with mandatory attributes with example values
        # model = InfoCampaign()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import sys
import unittest

import smscx_client
from smscx_client.model.info_delete_scheduled_msg import InfoDeleteScheduledMsg
globals()['InfoDeleteScheduledMsg'] = InfoDeleteScheduledMsg
from smscx_client.model.delete_scheduled_msg import DeleteScheduledMsg


class TestDeleteScheduledMsg(unittest.TestCase):
    """DeleteScheduledMsg unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testDeleteScheduledMsg(self):
        """Test DeleteScheduledMsg"""
        # FIXME: construct object with mandatory attributes with example values
        # model = DeleteScheduledMsg()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import unittest

import smscx_client
from smscx_client.api.sms_api import SmsApi  # noqa: E501


class TestSmsApi(unittest.TestCase):
    """SmsApi unit test stubs"""

    def setUp(self):
        self.api = SmsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_scheduled_sms(self):
        """Test case for delete_scheduled_sms

        Delete scheduled SMS  # noqa: E501
        """
        pass

    def test_delete_scheduled_sms_campaign(self):
        """Test case for delete_scheduled_sms_campaign

        Delete scheduled SMS campaign  # noqa: E501
        """
        pass

    def test_estimate_sms(self):
        """Test case for estimate_sms

        Estimate new SMS  # noqa: E501
        """
        pass

    def test_estimate_sms_campaign(self):
        """Test case for estimate_sms_campaign

        Estimate SMS campaign  # noqa: E501
        """
        pass

    def test_send_sms(self):
        """Test case for send_sms

        Send SMS  # noqa: E501
        """
        pass

    def test_send_sms_campaign(self):
        """Test case for send_sms_campaign

        Send SMS campaign  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



import re  # noqa: F401
import sys  # noqa: F401

from smscx_client.model_utils import (  # noqa: F401
    ApiTypeError,
    ModelComposed,
    ModelNormal,
    ModelSimple,
    cached_property,
    change_keys_js_to_python,
    convert_js_args_to_python_args,
    date,
    datetime,
    file_type,
    none_type,
    validate_get_composed_info,
    ApiModel
)
from smscx_client.exceptions import ApiAttributeError


def lazy_import():
    from smscx_client.model.original_network import OriginalNetwork
    from smscx_client.model.ported_network import PortedNetwork
    from smscx_client.model.roaming_network import RoamingNetwork
    globals()['OriginalNetwork'] = OriginalNetwork
    globals()['PortedNetwork'] = PortedNetwork
    globals()['RoamingNetwork'] = RoamingNetwork


class DataNumberLookup(ModelNormal):


    allowed_values = {
        ('status',): {
            'ACTIVE': "ACTIVE",
            'ABSENT': "ABSENT",
            'BARRED': "BARRED",
            'UNKNOWN': "UNKNOWN",
            'FAILED': "FAILED",
        },
    }

    validations = {
        ('lookup_id',): {
            'max_length': 36,
            'min_length': 36,
            'regex': {
                'pattern': r'^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$',  # noqa: E501
            },
        },
        ('country_iso',): {
            'max_length': 2,
            'min_length': 2,
        },
    }

    @cached_property
    def additional_properties_type():
        lazy_import()
        return (bool, date, datetime, dict, float, int, list, str, none_type,)  # noqa: E501

    _nullable = False

    @cached_property
    def api_types():
        """
        Returns
            api_types (dict): The key is attribute name
                and the value is attribute type.
        """
        lazy_import()
        return {
            'phone_number': (str,),  # noqa: E501
            'lookup_id': (str,),  # noqa: E501
            'cost': (float,),  # noqa: E501
            'mcc': (str,),  # noqa: E501
            'mccmnc': (str,),  # noqa: E501
            'country_iso': (str,),  # noqa: E501
            'country_name': (str,),  # noqa: E501
            'country_name_locale': (str,),  # noqa: E501
            'status': (str,),  # noqa: E501
            'status_description': (str,),  # noqa: E501
            'ported': (bool,),  # noqa: E501
            'roaming': (bool,),  # noqa: E501
            'original_network': (OriginalNetwork,),  # noqa: E501
            'ported_network': (PortedNetwork,),  # noqa: E501
            'roaming_network': (RoamingNetwork,),  # noqa: E501
            'datetime': (datetime,),  # noqa: E501
        }

    @cached_property
    def discriminator():
        return None


    attribute_map = {
        'phone_number': 'phoneNumber',  # noqa: E501
        'lookup_id': 'lookupId',  # noqa: E501
        'cost': 'cost',  # noqa: E501
        'mcc': 'mcc',  # noqa: E501
        'mccmnc': 'mccmnc',  # noqa: E501
        'country_iso': 'countryIso',  # noqa: E501
        'country_name': 'countryName',  # noqa: E501
        'country_name_locale': 'countryNameLocale',  # noqa: E501
        'status': 'status',  # noqa: E501
        'status_description': 'statusDescription',  # noqa: E501
        'ported': 'ported',  # noqa: E501
        'roaming': 'roaming',  # noqa: E501
        'original_network': 'originalNetwork',  # noqa: E501
        'ported_network': 'portedNetwork',  # noqa: E501
        'roaming_network': 'roamingNetwork',  # noqa: E501
        'datetime': 'datetime',  # noqa: E501
    }

    read_only_vars = {
    }

    _composed_schemas = {}

    @classmethod
    @convert_js_args_to_python_args
    def _from_api_data(cls, phone_number, lookup_id, cost, mcc, mccmnc, country_iso, country_name, country_name_locale, status, status_description, ported, roaming, original_network, ported_network, roaming_network, datetime, *args, **kwargs):  # noqa: E501
        """DataNumberLookup - a model

        Args:
            phone_number (str): Phone number in international E.164 format
            lookup_id (str): Unique lookup identifier
            cost (float): The cost of phone number lookup
            mcc (str): Mobile country code. [See full list of MCC](https://www.itu.int/dms_pub/itu-t/opb/sp/T-SP-E.212B-2018-PDF-E.pdf)
            mccmnc (str): Mobile country code + Mobile network code. [See full list of MCC + MNC](https://www.itu.int/dms_pub/itu-t/opb/sp/T-SP-E.212B-2018-PDF-E.pdf)
            country_iso (str): Two-letter country code in ISO-3166 alpha 2 standard of the destinations. Eg. `DE`, `FR`, `IT`
            country_name (str): Name of the country of the phone number
            country_name_locale (str): Name of the country in local language
            status (str): Status of the phone number
            status_description (str): Short description of the status
            ported (bool): Returns `true` if the phone number is ported to other mobile network, `false` otherwise
            roaming (bool): Returns `true` if the phone number is roaming in other network, `false` otherwise
            original_network (OriginalNetwork):
            ported_network (PortedNetwork):
            roaming_network (RoamingNetwork):
            datetime (datetime): Date and time of the phone number lookup request


        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', True)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        self = super(ApiModel, cls).__new__(cls)

        if args:
            for arg in args:
                if isinstance(arg, dict):
                    kwargs.update(arg)
                else:
                    raise ApiTypeError(
                        "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                            args,
                            self.__class__.__name__,
                        ),
                        path_to_item=_path_to_item,
                        valid_classes=(self.__class__,),
                    )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        self.phone_number = phone_number
        self.lookup_id = lookup_id
        self.cost = cost
        self.mcc = mcc
        self.mccmnc = mccmnc
        self.country_iso = country_iso
        self.country_name = country_name
        self.country_name_locale = country_name_locale
        self.status = status
        self.status_description = status_description
        self.ported = ported
        self.roaming = roaming
        self.original_network = original_network
        self.ported_network = ported_network
        self.roaming_network = roaming_network
        self.datetime = datetime
        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
        return self

    required_properties = set([
        '_data_store',
        '_check_type',
        '_spec_property_naming',
        '_path_to_item',
        '_configuration',
        '_visited_composed_classes',
    ])

    @convert_js_args_to_python_args
    def __init__(self, phone_number, lookup_id, cost, mcc, mccmnc, country_iso, country_name, country_name_locale, status, status_description, ported, roaming, original_network, ported_network, roaming_network, datetime, *args, **kwargs):  # noqa: E501
        """DataNumberLookup - a model

        Args:
            phone_number (str): Phone number in international E.164 format
            lookup_id (str): Unique lookup identifier
            cost (float): The cost of phone number lookup
            mcc (str): Mobile country code. [See full list of MCC](https://www.itu.int/dms_pub/itu-t/opb/sp/T-SP-E.212B-2018-PDF-E.pdf)
            mccmnc (str): Mobile country code + Mobile network code. [See full list of MCC + MNC](https://www.itu.int/dms_pub/itu-t/opb/sp/T-SP-E.212B-2018-PDF-E.pdf)
            country_iso (str): Two-letter country code in ISO-3166 alpha 2 standard of the destinations. Eg. `DE`, `FR`, `IT`
            country_name (str): Name of the country of the phone number
            country_name_locale (str): Name of the country in local language
            status (str): Status of the phone number
            status_description (str): Short description of the status
            ported (bool): Returns `true` if the phone number is ported to other mobile network, `false` otherwise
            roaming (bool): Returns `true` if the phone number is roaming in other network, `false` otherwise
            original_network (OriginalNetwork):
            ported_network (PortedNetwork):
            roaming_network (RoamingNetwork):
            datetime (datetime): Date and time of the phone number lookup request


        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        if args:
            for arg in args:
                if isinstance(arg, dict):
                    kwargs.update(arg)
                else:
                    raise ApiTypeError(
                        "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                            args,
                            self.__class__.__name__,
                        ),
                        path_to_item=_path_to_item,
                        valid_classes=(self.__class__,),
                    )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        self.phone_number = phone_number
        self.lookup_id = lookup_id
        self.cost = cost
        self.mcc = mcc
        self.mccmnc = mccmnc
        self.country_iso = country_iso
        self.country_name = country_name
        self.country_name_locale = country_name_locale
        self.status = status
        self.status_description = status_description
        self.ported = ported
        self.roaming = roaming
        self.original_network = original_network
        self.ported_network = ported_network
        self.roaming_network = roaming_network
        self.datetime = datetime
        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
            if var_name in self.read_only_vars:
                raise ApiAttributeError(f"`{var_name}` is a read-only attribute. Use `from_api_data` to instantiate "
                                     f"class with read only attributes.")



import sys
import unittest

import smscx_client
from smscx_client.model.reports_summary_source_response_data_value import ReportsSummarySourceResponseDataValue
globals()['ReportsSummarySourceResponseDataValue'] = ReportsSummarySourceResponseDataValue
from smscx_client.model.reports_summary_source_response import ReportsSummarySourceResponse


class TestReportsSummarySourceResponse(unittest.TestCase):
    """ReportsSummarySourceResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testReportsSummarySourceResponse(self):
        """Test ReportsSummarySourceResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ReportsSummarySourceResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import sys
import unittest

import smscx_client
from smscx_client.model.account_balance import AccountBalance


class TestAccountBalance(unittest.TestCase):
    """AccountBalance unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testAccountBalance(self):
        """Test AccountBalance"""
        # FIXME: construct object with mandatory attributes with example values
        # model = AccountBalance()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import sys
import unittest

import smscx_client
from smscx_client.model.info_id import InfoId
globals()['InfoId'] = InfoId
from smscx_client.model.shortlink_delete_response import ShortlinkDeleteResponse


class TestShortlinkDeleteResponse(unittest.TestCase):
    """ShortlinkDeleteResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testShortlinkDeleteResponse(self):
        """Test ShortlinkDeleteResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ShortlinkDeleteResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import sys
import unittest

import smscx_client
from smscx_client.model.info_optout import InfoOptout
globals()['InfoOptout'] = InfoOptout
from smscx_client.model.optouts_delete_response import OptoutsDeleteResponse


class TestOptoutsDeleteResponse(unittest.TestCase):
    """OptoutsDeleteResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testOptoutsDeleteResponse(self):
        """Test OptoutsDeleteResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = OptoutsDeleteResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import sys
import unittest

import smscx_client
from smscx_client.model.data_shortlink_hit import DataShortlinkHit
globals()['DataShortlinkHit'] = DataShortlinkHit
from smscx_client.model.call_back_request_attachment_hit import CallBackRequestAttachmentHit


class TestCallBackRequestAttachmentHit(unittest.TestCase):
    """CallBackRequestAttachmentHit unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCallBackRequestAttachmentHit(self):
        """Test CallBackRequestAttachmentHit"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CallBackRequestAttachmentHit()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import unittest

import smscx_client
from smscx_client.api.attachments_api import AttachmentsApi  # noqa: E501


class TestAttachmentsApi(unittest.TestCase):
    """AttachmentsApi unit test stubs"""

    def setUp(self):
        self.api = AttachmentsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_attachment(self):
        """Test case for delete_attachment

        Delete attachment  # noqa: E501
        """
        pass

    def test_export_attachment_hits_to_csv(self):
        """Test case for export_attachment_hits_to_csv

        Export attachment hits to CSV  # noqa: E501
        """
        pass

    def test_export_attachment_hits_to_xlsx(self):
        """Test case for export_attachment_hits_to_xlsx

        Export attachment hits to XLSX  # noqa: E501
        """
        pass

    def test_get_attachment_hits(self):
        """Test case for get_attachment_hits

        Get attachment hits  # noqa: E501
        """
        pass

    def test_get_attachments_list(self):
        """Test case for get_attachments_list

        Get attachments list  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



import sys
import unittest

import smscx_client
from smscx_client.model.error import Error
from smscx_client.model.model400_invalid_param_groups import Model400InvalidParamGroups
from smscx_client.model.model400_invalid_phone_numbers import Model400InvalidPhoneNumbers
globals()['Error'] = Error
globals()['Model400InvalidParamGroups'] = Model400InvalidParamGroups
globals()['Model400InvalidPhoneNumbers'] = Model400InvalidPhoneNumbers
from smscx_client.model.add_contacts_to_group400_response import AddContactsToGroup400Response


class TestAddContactsToGroup400Response(unittest.TestCase):
    """AddContactsToGroup400Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testAddContactsToGroup400Response(self):
        """Test AddContactsToGroup400Response"""
        # FIXME: construct object with mandatory attributes with example values
        # model = AddContactsToGroup400Response()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import sys
import unittest

import smscx_client
from smscx_client.model.info_otp import InfoOtp
globals()['InfoOtp'] = InfoOtp
from smscx_client.model.cancel_otp_response import CancelOtpResponse


class TestCancelOtpResponse(unittest.TestCase):
    """CancelOtpResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCancelOtpResponse(self):
        """Test CancelOtpResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CancelOtpResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import unittest

import smscx_client
from smscx_client.api.shortlinks_api import ShortlinksApi  # noqa: E501


class TestShortlinksApi(unittest.TestCase):
    """ShortlinksApi unit test stubs"""

    def setUp(self):
        self.api = ShortlinksApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_shortlink(self):
        """Test case for create_shortlink

        Create shortlink  # noqa: E501
        """
        pass

    def test_delete_shortlink(self):
        """Test case for delete_shortlink

        Delete shortlink  # noqa: E501
        """
        pass

    def test_export_shortlink_hits_to_csv(self):
        """Test case for export_shortlink_hits_to_csv

        Export shortlink hits to CSV  # noqa: E501
        """
        pass

    def test_export_shortlink_hits_to_xlsx(self):
        """Test case for export_shortlink_hits_to_xlsx

        Export shortlink hits to XLSX  # noqa: E501
        """
        pass

    def test_get_shortlink_hits(self):
        """Test case for get_shortlink_hits

        Get shortlink hits  # noqa: E501
        """
        pass

    def test_get_shortlinks_list(self):
        """Test case for get_shortlinks_list

        Get shortlinks list  # noqa: E501
        """
        pass

    def test_update_shortlink(self):
        """Test case for update_shortlink

        Update shortlink  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



import sys
import unittest

import smscx_client
from smscx_client.model.attachments import Attachments
from smscx_client.model.lookup import Lookup
from smscx_client.model.multichannel import Multichannel
from smscx_client.model.optouts import Optouts
from smscx_client.model.otp import Otp
from smscx_client.model.shortlinks import Shortlinks
from smscx_client.model.sms import Sms
from smscx_client.model.viber import Viber
from smscx_client.model.whatsapp import Whatsapp
globals()['Attachments'] = Attachments
globals()['Lookup'] = Lookup
globals()['Multichannel'] = Multichannel
globals()['Optouts'] = Optouts
globals()['Otp'] = Otp
globals()['Shortlinks'] = Shortlinks
globals()['Sms'] = Sms
globals()['Viber'] = Viber
globals()['Whatsapp'] = Whatsapp
from smscx_client.model.settings import Settings


class TestSettings(unittest.TestCase):
    """Settings unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSettings(self):
        """Test Settings"""
        # FIXME: construct object with mandatory attributes with example values
        # model = Settings()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import unittest

import smscx_client
from smscx_client.api.conversations_api import ConversationsApi  # noqa: E501


class TestConversationsApi(unittest.TestCase):
    """ConversationsApi unit test stubs"""

    def setUp(self):
        self.api = ConversationsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_conversation(self):
        """Test case for get_conversation

        Get conversation  # noqa: E501
        """
        pass

    def test_get_converstions_list(self):
        """Test case for get_converstions_list

        Get conversations list  # noqa: E501
        """
        pass

    def test_mark_conversation_as_read(self):
        """Test case for mark_conversation_as_read

        Mark conversation as read  # noqa: E501
        """
        pass

    def test_send_conversation_reply_sms(self):
        """Test case for send_conversation_reply_sms

        Send conversation reply via SMS  # noqa: E501
        """
        pass

    def test_send_conversation_reply_viber(self):
        """Test case for send_conversation_reply_viber

        Send conversation reply via Viber  # noqa: E501
        """
        pass

    def test_send_conversation_reply_whatsapp(self):
        """Test case for send_conversation_reply_whatsapp

        Send conversation reply via Whatsapp  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



import sys
import unittest

import smscx_client
from smscx_client.model.data_viber import DataViber
from smscx_client.model.info_viber import InfoViber
globals()['DataViber'] = DataViber
globals()['InfoViber'] = InfoViber
from smscx_client.model.send_viber_message_response import SendViberMessageResponse


class TestSendViberMessageResponse(unittest.TestCase):
    """SendViberMessageResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSendViberMessageResponse(self):
        """Test SendViberMessageResponse"""
        # FIXME: construct object with mandatory attributes with example values
        # model = SendViberMessageResponse()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



import re  # noqa: F401
import sys  # noqa: F401

from smscx_client.api_client import ApiClient, Endpoint as _Endpoint
from smscx_client.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from smscx_client.model.model400_invalid_param import Model400InvalidParam
from smscx_client.model.model401_unauthorized import Model401Unauthorized
from smscx_client.model.model403_insufficient_scope import Model403InsufficientScope
from smscx_client.model.model500_server_error import Model500ServerError
from smscx_client.model.oauth_token_response import OauthTokenResponse


class OauthApi(object):
    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.get_access_token_endpoint = _Endpoint(
            settings={
                'response_type': (OauthTokenResponse,),
                'auth': [
                    'BasicAuth'
                ],
                'endpoint_path': '/oauth/token',
                'operation_id': 'get_access_token',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'grant_type',
                    'scope',
                ],
                'required': [
                    'grant_type',
                ],
                'nullable': [
                ],
                'enum': [
                    'grant_type',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('grant_type',): {

                        "CLIENT_CREDENTIALS": "client_credentials"
                    },
                },
                'api_types': {
                    'grant_type':
                        (str,),
                    'scope':
                        (str,),
                },
                'attribute_map': {
                    'grant_type': 'grant_type',
                    'scope': 'scope',
                },
                'location_map': {
                    'grant_type': 'form',
                    'scope': 'form',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/x-www-form-urlencoded'
                ]
            },
            api_client=api_client
        )

    def get_access_token(
        self,
        grant_type="client_credentials",
        **kwargs
    ):
        """Get access token  # noqa: E501

        Generate an access token.    The POST request must use the HTTP Basic authentication scheme, by encoding `client_id:client_secret` string to Base64 string and use it in the header:    ```  Authorization: Basic czZCaGRSa3F0Mzo3RmpmcDBaQnIxS3REUmJuZlZkbUl3   ```    The request body should have the mandatory `grant_type` parameter with value `client_credentials`    The content type must be `application/x-www-form-urlencoded`.      
### Errors for POST `/oauth/token`  
| HTTP code  | Error code  | Type  | Description  |  
|:------------:|:------------:|:------------:| ------------ |  
|  400 | 1600  |  invalid_request  |  The request is missing a required parameter (grant_type) |  

|  400 | 1600  |  invalid_scope  |  The requested scope is invalid, unknown, or malformed |  

|  400 | 1600  |  unsupported_grant_type  |  The grant type is not supported (only client_credentials) |  
|  401 | 1600  |  invalid_client  |  Invalid client |  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_access_token(grant_type="client_credentials", async_req=True)
        >>> result = thread.get()

        Args:
            grant_type (str): Grant type (or flow) represents the methods through which the application will get Access Tokens. Must have value `client_credentials`. defaults to "client_credentials", must be one of ["client_credentials"]

        Keyword Args:
            scope (str): A list of space-delimited, case-sensitive strings. If left empty or ommited, the issued access token will be granted with all scopes (full privileges). [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            OauthTokenResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['grant_type'] = \
            grant_type
        return self.get_access_token_endpoint.call_with_http_info(**kwargs)

